@@ -1,6 +1,8 @@
 from .loss import l1_loss, entropy_logic_loss
+from .prune import prune_equal_fanin
 
 __all__ = [
     'entropy_logic_loss',
     'l1_loss',
+    'prune_equal_fanin',
 ]
